pub enum StatsPoll {
Pending,
Landed,
Failed,
}Expand description
State of a stats readback after a poll.
Variants
Pending
A readback has begun and not finished.
Landed
No readback is in flight, and either no readback has begun or the latest one to finish succeeded.
Failed
No readback is in flight, and the latest one to finish failed and left the earlier values in place.