#[non_exhaustive]pub struct SimulationViews<'a> {
pub grid: Option<GridView<'a>>,
pub points: Option<PointView<'a>>,
pub edges: Option<EdgeView<'a>>,
}Expand description
Views of one model, prepared together and borrowed from its state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.grid: Option<GridView<'a>>Grid of a CPU grid model, or the field layer of a CPU agent model that has one.
points: Option<PointView<'a>>Agents or nodes of a CPU agent or network model.
edges: Option<EdgeView<'a>>Edges of a CPU network model.